# Changelog

## 0.10.1 (2026-01-17)

Full Changelog: [v0.10.0...v0.10.1](https://github.com/reminix-ai/reminix-python/compare/v0.10.0...v0.10.1)

### Chores

* remove custom code ([79c273d](https://github.com/reminix-ai/reminix-python/commit/79c273d72db4818959779ab6b6ebbfc2cdc52d22))

## 0.10.0 (2026-01-17)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/reminix-ai/reminix-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([f764bc7](https://github.com/reminix-ai/reminix-python/commit/f764bc79fd4d7cde1bb3c15944da72d52a22fe02))
* **api:** api update ([6dbfa45](https://github.com/reminix-ai/reminix-python/commit/6dbfa45fb21c2e5504816ee838b98d67ae5d7dbb))
* **api:** manual updates ([a23228c](https://github.com/reminix-ai/reminix-python/commit/a23228cb66f67e5c0330fc30e7f96b1b4152f61e))
* **api:** manual updates ([4c38972](https://github.com/reminix-ai/reminix-python/commit/4c38972a8eaf4ff3ef208ef09f8fb571d41f7183))


### Chores

* remove custom code ([5ab7a67](https://github.com/reminix-ai/reminix-python/commit/5ab7a67e7bbc9787b950db1304a1fd1a7c60e38d))

## 0.9.0 (2026-01-17)

Full Changelog: [v0.8.4...v0.9.0](https://github.com/reminix-ai/reminix-python/compare/v0.8.4...v0.9.0)

### Features

* **api:** manual updates ([80a044a](https://github.com/reminix-ai/reminix-python/commit/80a044adc7397ff4838483286162b91648d1a085))

## 0.8.4 (2026-01-17)

Full Changelog: [v0.8.3...v0.8.4](https://github.com/reminix-ai/reminix-python/compare/v0.8.3...v0.8.4)

### Chores

* **internal:** update `actions/checkout` version ([b532210](https://github.com/reminix-ai/reminix-python/commit/b53221011c7a0d3e92ad22781f86a13b0be211b8))

## 0.8.3 (2026-01-16)

Full Changelog: [v0.8.2...v0.8.3](https://github.com/reminix-ai/reminix-python/compare/v0.8.2...v0.8.3)

### Features

* **api:** api update ([5048f43](https://github.com/reminix-ai/reminix-python/commit/5048f43b04992d99119c376bfaada081c48cbb85))
* **api:** manual updates ([d1569d9](https://github.com/reminix-ai/reminix-python/commit/d1569d9c9f384e9b63395dbfa0289ce7ad2ea792))
* **api:** manual updates ([d3d130d](https://github.com/reminix-ai/reminix-python/commit/d3d130d220094e70bc86f4eeeb2d92a7bae0aa25))
* **api:** manual updates ([441c124](https://github.com/reminix-ai/reminix-python/commit/441c12407bd14cb1fe0d2b6b1571fb7506038d39))
* **api:** manual updates ([9730384](https://github.com/reminix-ai/reminix-python/commit/973038498334fd4b49503049b5465af8f8c4486b))
* **api:** manual updates ([784708e](https://github.com/reminix-ai/reminix-python/commit/784708ef61ccfaec625574d473d7a58101a70464))
* **api:** manual updates ([8374976](https://github.com/reminix-ai/reminix-python/commit/837497673eccca998daa70b2828b2151daa3f137))
* **api:** manual updates ([d61bc7b](https://github.com/reminix-ai/reminix-python/commit/d61bc7bb592fbed2b41a1925bfeb8b1ad8a746ba))
* **client:** add support for binary request streaming ([fe247cc](https://github.com/reminix-ai/reminix-python/commit/fe247cce53d324fcedd1f5f5d2c28a52bd59a509))


### Chores

* remove custom code ([7699660](https://github.com/reminix-ai/reminix-python/commit/7699660edb5709313396025da780604abc4579da))

## 0.8.2 (2026-01-13)

Full Changelog: [v0.8.1...v0.8.2](https://github.com/reminix-ai/reminix-python/compare/v0.8.1...v0.8.2)

### Features

* **api:** api update ([21350dc](https://github.com/reminix-ai/reminix-python/commit/21350dcb9e608eb569855b54c8f5ea5e33b7b4ea))

## 0.8.1 (2026-01-13)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/reminix-ai/reminix-python/compare/v0.8.0...v0.8.1)

### Features

* add streaming support for chat and invoke methods ([7ddc828](https://github.com/reminix-ai/reminix-python/commit/7ddc8286b7c81a30289ef23dff210bfc4dbdf8b1))
* add streaming support for chat and invoke methods ([42ed11e](https://github.com/reminix-ai/reminix-python/commit/42ed11e9358c7353c0e33e0623a19b9b38c7b064))


### Bug Fixes

* add return type annotation to async example ([69fb5ff](https://github.com/reminix-ai/reminix-python/commit/69fb5ffa2134b9fa06707b9f7d7538d5a92ec1a2))
* remove duplicate imports from merge conflict ([19fe51b](https://github.com/reminix-ai/reminix-python/commit/19fe51b1436e633644ee4a2bc139668f9273387d))

## 0.8.0 (2026-01-13)

Full Changelog: [v0.0.1...v0.8.0](https://github.com/reminix-ai/reminix-python/compare/v0.0.1...v0.8.0)

### Chores

* update SDK settings ([9afabab](https://github.com/reminix-ai/reminix-python/commit/9afabab1c4874729441334cb49d162dfcd21a9e2))
* update SDK settings ([9450d09](https://github.com/reminix-ai/reminix-python/commit/9450d096f52ad8d13531c4242d29498bcc07fa62))
